@@ -124,18 +124,24 @@ def test_translate_table_expansion(compiler):
                 {
                     "scalarFunction": {
                         "functionReference": 1,
-                        "args": [
+                        "arguments": [
                             {
-                                "selection": {
-                                    "directReference": {"structField": {}},
-                                    "rootReference": {},
-                                }
+                                "value": {
+                                    "selection": {
+                                        "directReference": {"structField": {}},
+                                        "rootReference": {},
+                                    },
+                                },
                             },
                             {
-                                "selection": {
-                                    "directReference": {"structField": {"field": 1}},
-                                    "rootReference": {},
-                                }
+                                "value": {
+                                    "selection": {
+                                        "directReference": {
+                                            "structField": {"field": 1},
+                                        },
+                                        "rootReference": {},
+                                    },
+                                },
                             },
                         ],
                         "outputType": {"i64": {"nullability": "NULLABILITY_NULLABLE"}},
@@ -295,3 +301,25 @@ def test_nested_struct_field_access(compiler):
     )
     result = translate(expr, compiler)
     assert result == expected
+
+
+def test_function_argument_usage(compiler):
+    t = ibis.table([("a", "int64")], name="t")
+    expr = t.a.count()
+
+    result = translate(expr, compiler)
+    # Check that there is an `arguments` field
+    # and that it has the expected `value`
+    expected = json_format.ParseDict(
+        {
+            "value": {
+                "selection": {
+                    "direct_reference": {"struct_field": {}},
+                    "root_reference": {},
+                },
+            },
+        },
+        stalg.FunctionArgument(),
+    )
+
+    assert result.arguments[0] == expected
